poll_events

Function poll_events 

pub fn poll_events() -> Subscription<()>
A subscription which notifies the program when it should poll for new updates and redraw (i.e. as a result of the host updating parameters or the audio thread updating the state of meters).