pub struct PollSubNotifier { /* private fields */ }Expand description
An atomic flag used to notify the program when it should poll for new updates
and redraw (i.e. as a result of the host updating parameters or the audio thread
updating the state of meters). This flag is polled every frame right before
drawing. If the flag is set then the poll_events subscription will be called.
Implementations