pub struct Application<P: Program> { /* private fields */ }Expand description
The underlying definition and configuration of an iced application.
You can use this API to create and run iced applications step by step—without coupling your logic to a trait or a specific type.
You can create an Application with the application helper.
Implementations
Sourceimpl<P: Program + Send> Application<P>
impl<P: Program + Send> Application<P>
Sourcepub fn run(self) -> impl Program
pub fn run(self) -> impl Program
Runs the Application
Sourcepub fn settings(self, settings: Settings) -> Self
pub fn settings(self, settings: Settings) -> Self
Sets the Settings that will be used to run the Application.
Sourcepub fn antialiasing(self, antialiasing: bool) -> Self
pub fn antialiasing(self, antialiasing: bool) -> Self
Sets the Settings::antialiasing of the Application.
Sourcepub fn default_font(self, default_font: Font) -> Self
pub fn default_font(self, default_font: Font) -> Self
Sets the default Font of the Application.
Sourcepub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Self
pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Self
Adds a font to the list of fonts that will be loaded at the start of the Application.
Sourcepub fn title(
self,
title: impl TitleFn<P::State>,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn title( self, title: impl TitleFn<P::State>, ) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the title of the Application.
Sourcepub fn subscription(
self,
f: impl Fn(&P::State) -> Subscription<P::Message>,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn subscription( self, f: impl Fn(&P::State) -> Subscription<P::Message>, ) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the subscription logic of the Application.
Sourcepub fn theme(
self,
f: impl ThemeFn<P::State, P::Theme>,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn theme( self, f: impl ThemeFn<P::State, P::Theme>, ) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the theme logic of the Application.
Sourcepub fn style(
self,
f: impl Fn(&P::State, &P::Theme) -> Style,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn style( self, f: impl Fn(&P::State, &P::Theme) -> Style, ) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the style logic of the Application.
Sourcepub fn scale_factor(
self,
f: impl Fn(&P::State) -> f32,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn scale_factor( self, f: impl Fn(&P::State) -> f32, ) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the scale factor of the Application.
Sourcepub fn executor<E>(
self,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>where
E: Executor,
pub fn executor<E>(
self,
) -> Application<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>where
E: Executor,
Sets the executor of the Application.
Sourcepub fn presets(
self,
presets: impl IntoIterator<Item = Preset<P::State, P::Message>>,
) -> Self
pub fn presets( self, presets: impl IntoIterator<Item = Preset<P::State, P::Message>>, ) -> Self
Sets the boot presets of the Application.
Presets can be used to override the default booting strategy of your application during testing to create reproducible environments.